Index: recipe_engine/recipe_api.py |
diff --git a/recipe_engine/recipe_api.py b/recipe_engine/recipe_api.py |
index 920cfb580be48e07c6ba9760681185d5926c25fa..28fd9dc20c959dcb84ef81318a79ed32afb1e954 100644 |
--- a/recipe_engine/recipe_api.py |
+++ b/recipe_engine/recipe_api.py |
@@ -446,11 +446,11 @@ class RecipeApiPlain(object): |
# module.resource('dir').join('subdir', 'file.py') |
return self._module.MODULE_DIRECTORY.join('resources', *path) |
- def package_resource(self, *path): |
+ def package_repo_resource(self, *path): |
"""Returns a resource path, where path is relative to the root of |
the package where this module is defined. |
""" |
- return self._module.PACKAGE_DIRECTORY.join(*path) |
+ return self._module.PACKAGE_REPO_ROOT.join(*path) |
@property |
def name(self): |
@@ -446,11 +446,11 @@ class RecipeApiPlain(object): |
"""Returns a resource path, where path is relative to the root of |
- the package where this module is defined. |
+ the package repo where this module is defined. |
""" |